# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Neste curso é ensinado como contribuir com projetos de código aberto

[![Build Status](https://www.travis-ci.com/Diweine/libpythonpro.svg?branch=main)](https://www.travis-ci.com/Diweine/libpythonpro)
[![Updates](https://pyup.io/repos/github/Diweine/libpythonpro/shield.svg)](https://pyup.io/repos/github/Diweine/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/Diweine/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/Diweine/libpythonpro/)

Suportada Versão 3 de Python.

Para instalar:
```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de código:
```console
flake8
```